//
//  PTRARControllerInterface.h
//  Pointr
//
//  Created by Pointr Labs on 07/02/19.
//  Copyright © 2019 Pointr. All rights reserved.
//

#import <ARKit/ARKit.h>

#import <PointrKit/PTRARCameraTransform.h>
#import <PointrKit/PTRListenerHelper.h>
#import <PointrKit/PTRARPath.h>
#import <PointrKit/PTRPathSession.h>

@class PTRArButton;
@class PTRARUserInterfaceConfiguration;

API_UNAVAILABLE(macos, watchos, tvos)
/// Enum for AR controller states
typedef NS_ENUM(NSInteger, PTRARControllerState) {
    /// Stopped
    PTRARSessionStopped = 0,
    /// Started
    PTRARSessionStarted = 1
};

API_UNAVAILABLE(macos, watchos, tvos)
/// Protocol for `PTRARControllerInterface` callbacks.
OBJC_EXPORT @protocol PTRARControllerDelegate<NSObject>

@optional

/// Called on every camera transform change.
/// @param transform Camera transform.
/// @param timestamp Timestamp.
/// @param state Tracking state.
/// @param stateReason Tracking state reason.
- (void)onARControllerUpdatedCameraTransform:(nonnull PTRARCameraTransform *)transform
                                   timestamp:(double)timestamp
                                       state:(ARTrackingState)state
                                 stateReason:(ARTrackingStateReason)stateReason API_AVAILABLE(ios(11));

/// Called when `PTRARControllerInterface` state changes.
/// @param state New state.
- (void)onARControllerChangedState:(PTRARControllerState)state;

/// Called when `PTRARControllerInterface`'s ready state changes.
/// @param isReady YES if ready, NO otherwise.
- (void)onARControllerChangedReadyState:(BOOL)isReady;

/// Called when `PTRPath` is updated.
/// @param path Updated path.
- (void)onARControllerUpdatedPath:(nullable PTRARPath *)path;

/// Called when AR path session state is updated
/// Useful for taking UI actions based on terminal states like Arrived/Aborted/Failed
/// @param state Path session state.
- (void)onARControllerUpdatedPathSessionState:(PTRPathSessionState)state;

@end

API_AVAILABLE(ios(11.0))
API_UNAVAILABLE(macos, watchos, tvos)
/// Main controller for Pointr's augmenting reality. From this controller you can access the `PTRArButton` to present
/// AR, or even launch the experience manually.
OBJC_EXPORT @protocol PTRARControllerInterface<NSObject>

PTR_GENERATE_LISTENER_DECLARATIONS(PTRARControllerDelegate)

/// `ARSession` associated with this controller.
@property (nonatomic, strong, nonnull) ARSession *arSession;

/**
 * User interface configuration let's you customize some UI elements of the AR experience.
 * By default it sets the defaultConfiguration.
 */
@property (strong, nonatomic, nonnull) PTRARUserInterfaceConfiguration *userInterfaceConfiguration;

/// Start the AR controller.
- (void)start;

/// Stop the AR controller.
- (void)stop;

/// Check is AR is ready to be triggered.
- (BOOL)isARReady;

/// Check if AR is supported on the current device.
- (BOOL)isARSupported;

@end
