//
//  PTRGeofenceEvent.h
//  Pointr
//
//  Created by Furkan Erdem Perşembe on 18.12.2018.
//

#import <Foundation/Foundation.h>

NS_ASSUME_NONNULL_BEGIN

/// Enum for geofence evernt type
typedef NS_ENUM(int, PTRGeofenceEventType) {
    /// Enter event.
    PTRGeofenceEventTypeEnter = 0,
    /// Exit event.
    PTRGeofenceEventTypeExit = 1
};

@class PTRGeofence;

/// Geofence event class.
OBJC_EXPORT @interface PTRGeofenceEvent : NSObject

/**
 * Identifier of Event Object
 */
@property (nonatomic, assign, readonly) long identifier;

/**
 * Url of Event Notification
 */
@property (nonatomic, strong, readonly) NSString *url;

/**
 * Title of Event Notification
 */
@property (nonatomic, strong, readonly) NSString *title;

/**
 * Message of Event Notification
 */
@property (nonatomic, strong, readonly) NSString *message;

/**
 * Dwell Time of Event
 */
@property (nonatomic, assign, readonly) int dwellTimeInSeconds;

/**
 * Start Date of Event
 */
@property (nonatomic, strong, readonly) NSDate *startDate;

/**
 * End Date of Event
 */
@property (nonatomic, strong, readonly) NSDate *endDate;

/**
 * Type of Geofence Event
 */
@property (nonatomic, assign, readonly) PTRGeofenceEventType type;

/**
 * Geofence that triggered the event
 */
@property (nonatomic, strong, readonly) PTRGeofence *geofence;

/**
 * Check if the event is internal, i.e. it is created by the SDK and not defined by the user on PC
 */
@property (assign, nonatomic, readonly) BOOL isInternal;

- (instancetype)init NS_UNAVAILABLE;

@end

NS_ASSUME_NONNULL_END
