//
//  PTRPoi.h
//
//  Created by Pointr on 14/07/15
//  Copyright (c) 2015 Pointr Labs Ltd. All rights reserved.
//

#import <PointrKit/PTRFeature.h>

NS_ASSUME_NONNULL_BEGIN

/**
 *  Object representing pointr of interests.
 */
OBJC_EXPORT @interface PTRPoi : PTRFeature

/**
 *  Title of the point of interest
 */
@property (nonatomic, readonly) NSString *title;

/**
 *  Detailed description for point of interest.
 */
@property (nonatomic, readonly) NSString *_Nullable longDescription;

/**
 *  Keywords related to pointr of interest/
 */
@property (nonatomic, readonly)
    NSArray<NSString *> *_Nullable keywords;  // Array of keywords (originally separated by comma)

/**
 *  A dictionary representing any extra information.
 */
@property (nonatomic, readonly) NSDictionary<NSString *, NSObject *> *_Nullable extraData;

/**
 *  Url of icon given from backend
 */
@property (nonatomic, readonly) NSString *_Nullable iconUrl;

/**
 *  Url of image given from backend
 */
@property (nonatomic, readonly) NSString *_Nullable imageUrl;

- (instancetype)init NS_UNAVAILABLE;

/////////////////////////////////////////////////////////////////////////
#pragma mark - Public methods
/////////////////////////////////////////////////////////////////////////
/**
 Queries whether a given keyword is among the list of the Poi's keyword list

 @param keyword The keyword to be searched
 @return True if the keyword exist within the list;
 */
- (BOOL)containsKeyword:(NSString *_Nonnull)keyword;

@end

NS_ASSUME_NONNULL_END
