//
//  PTRPositioningTypes.h
//
//
//  Created by Pointr on 07/12/14.
//  Copyright (c) 2014 Pointr. All rights reserved.
//

#import <Foundation/Foundation.h>

/**
 * Class that contains positioning related constants and utility methods
 */
OBJC_EXPORT @interface PTRPositioningTypes : NSObject

/// Invalid building
+ (int)invalidBuilding;

/// Invalid site
+ (int)invalidSite;

/// Invalid float
+ (float)invalidFloat;

/// Invalid integer
+ (int)invalidInteger;

#pragma mark - Utility methods

/// Method to check if major and minor pair is valid
/// @param major Major
/// @param minor Minor
+ (bool)isValidMajor:(UInt16)major minor:(UInt16)minor;

/// Method to check if rssi is valid
/// @param rssi rssi
+ (bool)isValidRssi:(NSInteger)rssi;

@end

/// Enum of heading accuracy classes
typedef NS_ENUM(NSUInteger, PTRHeadingAccuracyClass) {
    /// Low
    PTRHeadingAccuracyClassLow,
    /// High
    PTRHeadingAccuracyClassHigh
};

/// Enum for location states
typedef NS_ENUM(NSUInteger, PTRLocationState) {
    /// Lost
    PTRLocationStateLost,
    /// Faded
    PTRLocationStateFaded,
    /// Active
    PTRLocationStateActive,
    /// Unknown
    PTRLocationStateUnknown
};

/// Enum for location types
typedef NS_ENUM(NSUInteger, PTRLocationType) {
    /// Unknown
    PTRLocationTypeUnknown = 0,
    /// Outdoor
    PTRLocationTypeOutdoor = 1,
    /// Transition
    PTRLocationTypeTransition = 2,
    /// Indoor
    PTRLocationTypeIndoor = 3
};

/// Enum for positioning service states
typedef NS_ENUM(NSUInteger, PTRPositioningServiceState) {
    /// Unknown yet (e.g. BT is powering up, or user is just presented a location authorisation dialog) DEFAULT
    PTRPositioningServiceUnknown,
    /// Authorised
    PTRPositioningServiceNotAuthorised,
    /// No bluetooth
    PTRPositioningServiceNoBluetooth,
    /// Unsupported hardware
    PTRPositioningServiceUnsupportedHardware,
    /// Not started
    PTRPositioningServiceNotStarted,
    /// Callback given when an error in CB appears
    /// It is due to Apple's bug failing updating CB state when a peripheral falsely disconnected
    /// No programmatic solution for this issue only closing and opening BT fixes issue
    /// [Please check: https://forums.developer.apple.com/thread/83852]
    PTRPositioningServiceError,
    /// Service Ok.
    PTRPositioningServiceOK
};

/** Constants for PTRGpsAccuracyMode
 *  Normal Gps Services runs for 1-6
 *  Significant Location Services runs for 7 and 0
 */
typedef NS_ENUM(int, PTRGpsAccuracyMode) {
    /** PTRGpsAccuracyModeUnknown */
    PTRGpsAccuracyModeUnknown = 0,
    /** PTRGpsAccuracyModeBestForNavigation */
    PTRGpsAccuracyModeBestForNavigation = 1,
    /** PTRGpsAccuracyModeBest */
    PTRGpsAccuracyModeBest = 2,
    /** PTRGpsAccuracyModeNearestTenMeters */
    PTRGpsAccuracyModeNearestTenMeters = 3,
    /** PTRGpsAccuracyModeHundredMeters */
    PTRGpsAccuracyModeHundredMeters = 4,
    /** PTRGpsAccuracyModeKilometer */
    PTRGpsAccuracyModeKilometer = 5,
    /** PTRGpsAccuracyModeThreeKilometers */
    PTRGpsAccuracyModeThreeKilometers = 6,
    /** PTRGpsAccuracyModeSignificantUpdatesOnly */
    PTRGpsAccuracyModeSignificantUpdatesOnly = 7  // DEFAULT
};

/** Constants for PTRActivityType
 *  Matches CoreLocation.CLActivityType
 */
typedef NS_ENUM(int, PTRActivityType) {
    /** PTRActivityTypeUnknown */
    PTRActivityTypeUnknown = 0,
    /** PTRActivityTypeOther */
    PTRActivityTypeOther = 1,
    /** PTRActivityTypeAutomotiveNavigation */
    PTRActivityTypeAutomotiveNavigation = 2,
    /** PTRActivityTypeFitness */
    PTRActivityTypeFitness = 3,
    /** PTRActivityTypeOtherNavigation */
    PTRActivityTypeOtherNavigation = 4,
    /** PTRActivityTypeAirborne */
    PTRActivityTypeAirborne = 5
};
