//
//  PTRFeature.h
//
//  Created by Pointr on 23/06/2022.
//  Copyright © 2022 Pointr. All rights reserved.
//

#import <Foundation/Foundation.h>

#import <PointrKit/PTRLocationAware.h>

@class PTRGeometry;

NS_ASSUME_NONNULL_BEGIN

/// Model class for feature. A feature represents a map object.
@interface PTRFeature : PTRLocationAware

/// Feature's unique identifier.
@property (strong, nonatomic, readonly) NSString *identifier;

/// Feature's external identifier.
@property (strong, nonatomic, readonly) NSString *externalId;

/// Feature's type code.
@property (strong, nonatomic, readonly) NSString *typeCode;

/// Feature's geometry.
@property (strong, nonatomic, readonly) PTRGeometry *geometry;

/// Feature's attributes.
@property (strong, nonatomic, readonly) NSDictionary<NSString *, id> *attributes;

- (instancetype)init NS_UNAVAILABLE;

/// Initialiser with properties.
/// - Parameters:
///   - typeCode: Feature's type code.
///   - geometry: Feature's geometry.
///   - location: Feature's location.
///   - externalId: Feature's external identifier. You can set it for your own use. This parameter is optional.
///   - attributes: Dictionary with custom attributes to be added to the feature. This parameter is optional. Only objects of type `Array`, `Number` and `String` can be added to the attributes. Custom classes are not supported.
- (instancetype)initWithTypeCode:(nonnull NSString *)typeCode
                        geometry:(nonnull PTRGeometry *)geometry
                        location:(nonnull PTRLocation *)location
                      externalId:(nullable NSString *)externalId
                      attributes:(nullable NSDictionary<NSString *, id> *)attributes;

/// Initialiser with geoJson.
/// - Parameter geoJsonString: GeoJson string.
- (instancetype)initWithGeoJson:(NSString *)geoJsonString;

/// Method to access the custom attributes based on key.
/// - Parameter key: The key of the custom attribute.
- (id)attributeForKey:(NSString *)key;

@end

NS_ASSUME_NONNULL_END
