//
//  PTRGraphManagerInterface.h
//  Pointr
//
//  Created by Pointr Labs on 21/03/16.
//  Copyright © 2016 Pointr. All rights reserved.
//

#import <PointrKit/PTRListenerHelper.h>
#import <PointrKit/PTRSite.h>

NS_ASSUME_NONNULL_BEGIN

/**
 *  Keeps track of Graph related updates.
 */
OBJC_EXPORT @protocol PTRGraphManagerDelegate<NSObject>

@optional
/**
 *  Called when graph for a specific site is changed
 */
- (void)onGraphManagerChangedGraphForSite:(nonnull PTRSite *)site;

@end

/**
 * Main interface to manage accessing Graph content
 * @warn This class deals with content only, for pathfinding see @PTRPathManagerInterface
 */
OBJC_EXPORT @protocol PTRGraphManagerInterface<NSObject>

PTR_GENERATE_LISTENER_DECLARATIONS(PTRGraphManagerDelegate)

/////////////////////////////////////////////////////////////////////////
#pragma mark - Public methods
/////////////////////////////////////////////////////////////////////////

/**
 * Checks whether the Graph content is present & ready for the given site
 * @param siteId internal site id
 * @return BOOL Graph content is present & ready for the given site
 */
- (BOOL)hasContentForSite:(int)siteId;

@end

NS_ASSUME_NONNULL_END
